==> TundereBird-0.24.tar.bz2: TundereBird-0.24/core/Smdn.Net.Imap4.Client/Smdn.Net.Imap4/ImapUpdatedStatus.cs <==
// 
// Author:
//       smdn <smdn@mail.invisiblefulmoon.net>
// 
// Copyright (c) 2008-2010 smdn
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;

namespace Smdn.Net.Imap4 {
  // 7.2. Server Responses - Server and Mailbox Status
  // 7.2.6. FLAGS Response
  // 7.3. Server Responses - Mailbox Size
  // 7.3.1. EXISTS Response
  // 7.3.2. RECENT Response
  // 7.4. Server Responses - Message Status
  // 7.4.1. EXPUNGE Response
  // 7.4.2. FETCH Response
  public class ImapUpdatedStatus {
    public ImapUpdatedStatusKind UpdatedKind {
      get { return updatedKind; }
    }

    public ImapMessageFlagList Flags {
      get { return flags; }
    }

    [CLSCompliant(false)]
    public IImapMessageDynamicAttribute[] MessageAttributes {
      get { return messageAttributes; }
    }

    public long[] Expunged {
      get { return expunged; }
    }

    public long? Exists {
      get { return exists; }
    }

    public long? Recent {
      get { return recent; }
    }

    public static ImapUpdatedStatus CreateFlagsUpdated(ImapMessageFlagList flags)
    {
      if (flags == null)
        throw new ArgumentNullException("flags");

      return new ImapUpdatedStatus(flags, new IImapMessageDynamicAttribute[] {}, new long[] {}, null, null);
    }

    [CLSCompliant(false)]
    public static ImapUpdatedStatus CreateMessageAttributeUpdated(IImapMessageDynamicAttribute messageAttribute)
    {
      if (messageAttribute == null)
        throw new ArgumentNullException("messageAttribute");

      return CreateMessageAttributeUpdated(new[] {messageAttribute});
    }

    [CLSCompliant(false)]
    public static ImapUpdatedStatus CreateMessageAttributeUpdated(IImapMessageDynamicAttribute[] messageAttributes)
    {
      if (messageAttributes == null)
        throw new ArgumentNullException("messageAttributes");

      return new ImapUpdatedStatus(null, messageAttributes, new long[] {}, null, null);
    }

    public static ImapUpdatedStatus CreateExpungedUpdated(long expunged)
    {
      return CreateExpungedUpdated(new[] {expunged});
    }

    public static ImapUpdatedStatus CreateExpungedUpdated(long[] expunged)
    {
      if (expunged == null)
        throw new ArgumentNullException("expunged");

      return new ImapUpdatedStatus(null, new IImapMessageDynamicAttribute[] {}, expunged, null, null);
    }

    public static ImapUpdatedStatus CreateExistsUpdated(long exists)
    {
      return new ImapUpdatedStatus(null, new IImapMessageDynamicAttribute[] {}, new long[] {}, exists, null);
    }

    public static ImapUpdatedStatus CreateRecentUpdated(long recent)
    {
      return new ImapUpdatedStatus(null, new IImapMessageDynamicAttribute[] {}, new long[] {}, null, recent);
    }

    public ImapUpdatedStatus()
      : this(null, new IImapMessageDynamicAttribute[] {}, new long[] {}, null, null)
    {
    }

    [CLSCompliant(false)]
    public ImapUpdatedStatus(ImapMessageFlagList flags, IImapMessageDynamicAttribute messageAttribute, long? expunged, long? exists, long? recent)
      : this(flags,
             (messageAttribute == null) ? new IImapMessageDynamicAttribute[] {} : new[] {messageAttribute},
             (expunged == null) ? new long[] {} : new[] {expunged.Value},
             exists,
             recent)
    {
    }

    [CLSCompliant(false)]
    public ImapUpdatedStatus(ImapMessageFlagList flags, IImapMessageDynamicAttribute[] messageAttributes, long[] expunged, long? exists, long? recent)
    {
      if (messageAttributes == null)
        throw new ArgumentNullException("messageAttributes");
      if (expunged == null)
        throw new ArgumentNullException("expunged");

      this.flags = flags;
      this.messageAttributes = messageAttributes;
      this.expunged = expunged;
      this.exists = exists;
      this.recent = recent;
      this.updatedKind =
        ((flags == null)                  ? ImapUpdatedStatusKind.None : ImapUpdatedStatusKind.Flags) |
        ((messageAttributes.Length == 0)  ? ImapUpdatedStatusKind.None : ImapUpdatedStatusKind.Messages) |
        ((expunged.Length == 0)           ? ImapUpdatedStatusKind.None : ImapUpdatedStatusKind.Expunged) |
        ((exists == null)                 ? ImapUpdatedStatusKind.None : ImapUpdatedStatusKind.Exists) |
        ((recent == null)                 ? ImapUpdatedStatusKind.None : ImapUpdatedStatusKind.Recent);
    }

    public ImapUpdatedStatus MergeWith(ImapUpdatedStatus other)
    {
      return new ImapUpdatedStatus(other.flags ?? this.flags,
                               this.messageAttributes.Concat(other.messageAttributes),
                               this.expunged.Concat(other.expunged),
                               other.exists ?? this.exists,
                               other.recent ?? this.recent);
    }

    public override string ToString()
    {
      return string.Format("{{UpdatedKind={0}, Messages={1}, Expunge={2}, Exists={3}, Recent={4}, Flags={5}}}",
                           updatedKind,
                           string.Join(",", Array.ConvertAll(messageAttributes, delegate(IImapMessageDynamicAttribute m) { return m.ToString(); })),
                           string.Join(",", Array.ConvertAll(expunged, delegate(long e) { return e.ToString(); })),
                           exists,
                           recent,
                           flags);
    }

    private /*readonly*/ ImapUpdatedStatusKind updatedKind;
    private /*readonly*/ ImapMessageFlagList flags;
    private /*readonly*/ IImapMessageDynamicAttribute[] messageAttributes;
    private /*readonly*/ long[] expunged;
    private /*readonly*/ long? exists;
    private /*readonly*/ long? recent;
  }
}

==> TundereBird-0.28.tar.bz2: TundereBird-0.28/core/Smdn.Net.Imap4.Client/Smdn.Net.Imap4/ImapUpdatedStatus.cs <==
// 
// Author:
//       smdn <smdn@mail.invisiblefulmoon.net>
// 
// Copyright (c) 2008-2010 smdn
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;

namespace Smdn.Net.Imap4 {
  // 7.2. Server Responses - Server and Mailbox Status
  // 7.2.6. FLAGS Response
  // 7.3. Server Responses - Mailbox Size
  // 7.3.1. EXISTS Response
  // 7.3.2. RECENT Response
  // 7.4. Server Responses - Message Status
  // 7.4.1. EXPUNGE Response
  // 7.4.2. FETCH Response
  public class ImapUpdatedStatus {
    public ImapUpdatedStatusKind UpdatedKind {
      get { return updatedKind; }
    }

    public IImapMessageFlagSet Flags {
      get { return flags; }
    }

    [CLSCompliant(false)]
    public IImapMessageDynamicAttribute[] MessageAttributes {
      get { return messageAttributes; }
    }

    public long[] Expunged {
      get { return expunged; }
    }

    public long? Exists {
      get { return exists; }
    }

    public long? Recent {
      get { return recent; }
    }

    public static ImapUpdatedStatus CreateFlagsUpdated(IImapMessageFlagSet flags)
    {
      if (flags == null)
        throw new ArgumentNullException("flags");

      return new ImapUpdatedStatus(flags, new IImapMessageDynamicAttribute[] {}, new long[] {}, null, null);
    }

    [CLSCompliant(false)]
    public static ImapUpdatedStatus CreateMessageAttributeUpdated(IImapMessageDynamicAttribute messageAttribute)
    {
      if (messageAttribute == null)
        throw new ArgumentNullException("messageAttribute");

      return CreateMessageAttributeUpdated(new[] {messageAttribute});
    }

    [CLSCompliant(false)]
    public static ImapUpdatedStatus CreateMessageAttributeUpdated(IImapMessageDynamicAttribute[] messageAttributes)
    {
      if (messageAttributes == null)
        throw new ArgumentNullException("messageAttributes");

      return new ImapUpdatedStatus(null, messageAttributes, new long[] {}, null, null);
    }

    public static ImapUpdatedStatus CreateExpungedUpdated(long expunged)
    {
      return CreateExpungedUpdated(new[] {expunged});
    }

    public static ImapUpdatedStatus CreateExpungedUpdated(long[] expunged)
    {
      if (expunged == null)
        throw new ArgumentNullException("expunged");

      return new ImapUpdatedStatus(null, new IImapMessageDynamicAttribute[] {}, expunged, null, null);
    }

    public static ImapUpdatedStatus CreateExistsUpdated(long exists)
    {
      return new ImapUpdatedStatus(null, new IImapMessageDynamicAttribute[] {}, new long[] {}, exists, null);
    }

    public static ImapUpdatedStatus CreateRecentUpdated(long recent)
    {
      return new ImapUpdatedStatus(null, new IImapMessageDynamicAttribute[] {}, new long[] {}, null, recent);
    }

    public ImapUpdatedStatus()
      : this(null, new IImapMessageDynamicAttribute[] {}, new long[] {}, null, null)
    {
    }

    [CLSCompliant(false)]
    public ImapUpdatedStatus(IImapMessageFlagSet flags, IImapMessageDynamicAttribute messageAttribute, long? expunged, long? exists, long? recent)
      : this(flags,
             (messageAttribute == null) ? new IImapMessageDynamicAttribute[] {} : new[] {messageAttribute},
             (expunged == null) ? new long[] {} : new[] {expunged.Value},
             exists,
             recent)
    {
    }

    [CLSCompliant(false)]
    public ImapUpdatedStatus(IImapMessageFlagSet flags, IImapMessageDynamicAttribute[] messageAttributes, long[] expunged, long? exists, long? recent)
    {
      if (messageAttributes == null)
        throw new ArgumentNullException("messageAttributes");
      if (expunged == null)
        throw new ArgumentNullException("expunged");

      this.flags = flags;
      this.messageAttributes = messageAttributes;
      this.expunged = expunged;
      this.exists = exists;
      this.recent = recent;
      this.updatedKind =
        ((flags == null)                  ? ImapUpdatedStatusKind.None : ImapUpdatedStatusKind.Flags) |
        ((messageAttributes.Length == 0)  ? ImapUpdatedStatusKind.None : ImapUpdatedStatusKind.Messages) |
        ((expunged.Length == 0)           ? ImapUpdatedStatusKind.None : ImapUpdatedStatusKind.Expunged) |
        ((exists == null)                 ? ImapUpdatedStatusKind.None : ImapUpdatedStatusKind.Exists) |
        ((recent == null)                 ? ImapUpdatedStatusKind.None : ImapUpdatedStatusKind.Recent);
    }

    public ImapUpdatedStatus MergeWith(ImapUpdatedStatus other)
    {
      return new ImapUpdatedStatus(other.flags ?? this.flags,
                               this.messageAttributes.Concat(other.messageAttributes),
                               this.expunged.Concat(other.expunged),
                               other.exists ?? this.exists,
                               other.recent ?? this.recent);
    }

    public override string ToString()
    {
      return string.Format("{{UpdatedKind={0}, Messages={1}, Expunge={2}, Exists={3}, Recent={4}, Flags={5}}}",
                           updatedKind,
                           string.Join(",", Array.ConvertAll(messageAttributes, delegate(IImapMessageDynamicAttribute m) { return m.ToString(); })),
                           string.Join(",", Array.ConvertAll(expunged, delegate(long e) { return e.ToString(); })),
                           exists,
                           recent,
                           flags);
    }

    private /*readonly*/ ImapUpdatedStatusKind updatedKind;
    private /*readonly*/ IImapMessageFlagSet flags;
    private /*readonly*/ IImapMessageDynamicAttribute[] messageAttributes;
    private /*readonly*/ long[] expunged;
    private /*readonly*/ long? exists;
    private /*readonly*/ long? recent;
  }
}
